@@ -1,5 +1,7 @@
 import blueness
+import bluer_academy
 import bluer_ai
+import abadpour
 import bluer_algo
 import bluer_options
 import bluer_objects
@@ -17,6 +19,14 @@ import gizai
 
 items = README.Items(
     [
+        {
+            "name": "blog",
+            "marquee": "https://github.com/kamangir/assets2/blob/main/blog/blog-v2.png?raw=true",
+            "description": "📜 kamangir writes here.",
+            "url": "https://github.com/kamangir/blog/issues",
+        }
+    ]
+    + [
         {
             "name": module.NAME,
             "marquee": module.MARQUEE,
@@ -37,6 +47,7 @@ items = README.Items(
             bluer_ugv,
             bluer_algo,
             bluer_flow,
+            bluer_academy,
             vancouver_watching,
             bluer_journal,
             bluer_options,
@@ -45,6 +56,7 @@ items = README.Items(
             bluer_sandbox,
             blueness,
             gizai,
+            abadpour,
         ]
     ]
 )
